@@ -1,6 +1,6 @@
 #' Get / Set SPSS missing values
 #'
-#' @param x A vector (or a data frame).
+#' @param x A vector, a data frame, or a survey design.
 #' @param value A vector of values that should also be considered as missing
 #' (for `na_values`) or a numeric vector of length two giving the (inclusive)
 #' extents of the range (for `na_values`, use `-Inf` and `Inf` if you
@@ -88,6 +88,14 @@ na_values.data.frame <- function(x) {
   lapply(x, na_values)
 }
 
+#' @export
+na_values.survey.design <- function(x) {
+  na_values(x$variables)
+}
+
+#' @export
+na_values.svyrep.design <- na_values.survey.design
+
 #' @rdname na_values
 #' @export
 `na_values<-` <- function(x, value) {
@@ -111,9 +119,8 @@ na_values.data.frame <- function(x) {
 
 #' @export
 `na_values<-.factor` <- function(x, value) {
-  if (!is.null(value)) {
-    stop("`na_values()` cannot be applied to factors.")
-  }
+  if (!is.null(value))
+    cli::cli_abort("{.fn na_values}` cannot be applied to factors.")
   x %>% remove_attributes("na_values")
 }
 
@@ -147,21 +154,19 @@ na_values.data.frame <- function(x) {
   }
 
   if (!all(names(value) %in% names(x))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(value), names(x)),
-      collapse = ", "
-    )
-    stop("some variables not found in x:", missing_names)
+    missing_names <- setdiff(names(value), names(x))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg x}."
+    ))
   }
 
   for (var in names(value)) {
     if (!is.null(value[[var]])) {
-      if (mode(x[[var]]) != mode(value[[var]])) {
-        stop("`x` and `value` must be same type",
-          call. = FALSE,
-          domain = "R-labelled"
-        )
-      }
+      if (mode(x[[var]]) != mode(value[[var]]))
+        cli::cli_abort(paste(
+          "{.arg x} ({class(x)}) and {.arg value} ({class(value)})",
+          "must be same type."
+        ))
       if (typeof(x[[var]]) != typeof(value[[var]])) {
         mode(value[[var]]) <- typeof(x[[var]])
       }
@@ -173,6 +178,14 @@ na_values.data.frame <- function(x) {
   x
 }
 
+#' @export
+`na_values<-.survey.design` <- function(x, value) {
+  na_values(x$variables) <- value
+  x
+}
+
+#' @export
+`na_values<-.svyrep.design` <- `na_values<-.survey.design`
 
 #' @rdname na_values
 #' @export
@@ -196,6 +209,14 @@ na_range.data.frame <- function(x) {
   lapply(x, na_range)
 }
 
+#' @export
+na_range.survey.design <- function(x) {
+  na_range(x$variables)
+}
+
+#' @export
+na_range.svyrep.design <- na_range.survey.design
+
 #' @rdname na_values
 #' @export
 `na_range<-` <- function(x, value) {
@@ -220,7 +241,7 @@ na_range.data.frame <- function(x) {
 #' @export
 `na_range<-.factor` <- function(x, value) {
   if (!is.null(value)) {
-    stop("`na_range()` cannot be applied to factors.")
+    cli::cli_abort("{.fn na_range} cannot be applied to factors.")
   }
   x %>% remove_attributes("na_range")
 }
@@ -255,21 +276,20 @@ na_range.data.frame <- function(x) {
   }
 
   if (!all(names(value) %in% names(x))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(value), names(x)),
-      collapse = ", "
-    )
-    stop("some variables not found in x:", missing_names)
+    missing_names <- setdiff(names(value), names(x))
+
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg x}."
+    ))
   }
 
   for (var in names(value)) {
     if (!is.null(value[[var]])) {
-      if (mode(x[[var]]) != mode(value[[var]])) {
-        stop("`x` and `value` must be same type",
-          call. = FALSE,
-          domain = "R-labelled"
-        )
-      }
+      if (mode(x[[var]]) != mode(value[[var]]))
+        cli::cli_abort(paste(
+          "{.arg x} ({class(x)}) and {.arg value} ({class(value)})",
+          "must be same type."
+        ))
       if (typeof(x[[var]]) != typeof(value[[var]])) {
         mode(value[[var]]) <- typeof(x[[var]])
       }
@@ -281,6 +301,15 @@ na_range.data.frame <- function(x) {
   x
 }
 
+#' @export
+`na_range<-.survey.design` <- function(x, value) {
+  na_range(x$variables) <- value
+  x
+}
+
+#' @export
+`na_range<-.svyrep.design` <- `na_range<-.survey.design`
+
 #' @rdname na_values
 #' @export
 get_na_values <- na_values
@@ -290,7 +319,7 @@ get_na_values <- na_values
 get_na_range <- na_range
 
 #' @rdname na_values
-#' @param .data a data frame or a vector
+#' @param .data a data frame, a survey design or a vector
 #' @param ... name-value pairs of missing values (see examples)
 #' @param .values missing values to be applied to the data.frame,
 #'   using the same syntax as `value` in `na_values(df) <- value` or
@@ -328,10 +357,24 @@ get_na_range <- na_range
 #' }
 #' @export
 set_na_values <- function(.data, ..., .values = NA, .strict = TRUE) {
-  if (!is.data.frame(.data) && !is.atomic(.data)) {
-    stop(".data should be a data.frame or a vector")
+
+  # survey case
+  if (inherits(.data, "survey.design") || inherits(.data, "svyrep.design")) {
+    .data$variables <-
+      set_na_values(
+        .data$variables,
+        ...,
+        .values = .values,
+        .strict = .strict
+      )
+    return(.data)
   }
 
+  if (!is.data.frame(.data) && !is.atomic(.data))
+    cli::cli_abort(
+      "{.arg .data} should be a data frame, a survey design or a vector."
+    )
+
   # vector case
   if (is.atomic(.data)) {
     if (!identical(.values, NA)) {
@@ -351,11 +394,10 @@ set_na_values <- function(.data, ..., .values = NA, .strict = TRUE) {
   }
   values <- rlang::dots_list(...)
   if (.strict && !all(names(values) %in% names(.data))) {
-    missing_names <- stringr::str_c(
-      setdiff(names(values), names(.data)),
-      collapse = ", "
-    )
-    stop("some variables not found in .data: ", missing_names)
+    missing_names <- setdiff(names(values), names(.data))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg .data}."
+    ))
   }
 
   for (v in intersect(names(values), names(.data))) {
@@ -368,10 +410,24 @@ set_na_values <- function(.data, ..., .values = NA, .strict = TRUE) {
 #' @rdname na_values
 #' @export
 set_na_range <- function(.data, ..., .values = NA, .strict = TRUE) {
-  if (!is.data.frame(.data) && !is.atomic(.data)) {
-    stop(".data should be a data.frame or a vector")
+
+  # survey case
+  if (inherits(.data, "survey.design") || inherits(.data, "svyrep.design")) {
+    .data$variables <-
+      set_na_range(
+        .data$variables,
+        ...,
+        .values = .values,
+        .strict = .strict
+      )
+    return(.data)
   }
 
+  if (!is.data.frame(.data) && !is.atomic(.data))
+    cli::cli_abort(
+      "{.arg .data} should be a data frame, a survey design or a vector."
+    )
+
   # vector case
   if (is.atomic(.data)) {
     if (!identical(.values, NA)) {
@@ -391,7 +447,10 @@ set_na_range <- function(.data, ..., .values = NA, .strict = TRUE) {
   }
   values <- rlang::dots_list(...)
   if (.strict && !all(names(values) %in% names(.data))) {
-    stop("some variables not found in .data")
+    missing_names <- setdiff(names(values), names(.data))
+    cli::cli_abort(c(
+      "Can't find variables {.var {missing_names}} in {.arg .data}."
+    ))
   }
 
   for (v in intersect(names(values), names(.data))) {
@@ -455,7 +514,14 @@ user_na_to_na.data.frame <- function(x) {
   x
 }
 
+#' @export
+user_na_to_na.survey.design <- function(x) {
+  x$variables <- user_na_to_na(x$variables)
+  x
+}
 
+#' @export
+user_na_to_na.svyrep.design <- user_na_to_na.survey.design
 
 #' @rdname na_values
 #' @export
@@ -479,3 +545,12 @@ user_na_to_tagged_na.data.frame <- function(x) {
   x[] <- lapply(x, user_na_to_tagged_na)
   x
 }
+
+#' @export
+user_na_to_tagged_na.survey.design <- function(x) {
+  x$variables <- user_na_to_tagged_na(x$variables)
+  x
+}
+
+#' @export
+user_na_to_tagged_na.svyrep.design <- user_na_to_tagged_na.survey.design
